### Name: tidem
### Title: Fit a tidal model to a timeseries
### Aliases: tidem
### Keywords: misc

### ** Examples

library(oce)
# Fake a week simple hourly data series (not sealevel object)
hour <- seq(0, 24 * 7)
# M2 tide with phase 45 degrees
eta <- 1 + 2 * sin(2 * pi * hour / 12.4206 + pi/4)
tide <- tidem(eta)
summary(tide)
# Check: only Z0 and M2 are significant
plot(tide)

# Supply a start time, using a sealevel object
t <- seq(0, 10*86400, 3600)             # 10 days
eta <- sin(0.080511401 * t * 2 * pi / 3600)
sl <- as.sealevel(eta,t+as.POSIXct("2009-02-13 00:00:00", tz="GMT"))
m <- tidem(sl, start.time=as.POSIXct("2009-02-13 00:00:00", tz="GMT"))
# Check: only M2 has non-negligible amplitude
summary(m)

# The demonstration time series from Foreman (1977),
# also used in T_TIDE (Pawlowicz, 2002).
data(sealevel.tuk)
tide.tuk <- tidem(sealevel.tuk)
summary(tide.tuk)



